package org.dasein.cloud.jclouds.azure;

import org.apache.log4j.Logger;
import org.dasein.cloud.AbstractCloud;
import org.dasein.cloud.ProviderContext;
import org.dasein.cloud.services.dc.DataCenterServices;
import org.dasein.cloud.services.storage.StorageServices;
import org.jclouds.blobstore.BlobStoreContext;
import org.jclouds.blobstore.BlobStoreContextFactory;

public class Azure extends AbstractCloud {
    static private final Logger logger = Logger.getLogger(Azure.class);
    
    public Azure() { }

    @Override
    public String getCloudName() {
        return "Azure";
    }

    public BlobStoreContext getAzureContext() {
        logger.debug("enter - getAzureContext()");
        try {
            ProviderContext ctx = getContext();
            String account = new String(ctx.getAccessPublic());
            String key = new String(ctx.getAccessPrivate());
            
            String userId = account + "/" + ctx.getAccountNumber();
                
            return (new BlobStoreContextFactory()).createContext("azureblob", userId, key);
        }
        finally {
            logger.debug("exit - getAzureContext()");
        }
    }
    
    private transient DataCenters dataCenterServices = null;
    
    @Override
    public DataCenterServices getDataCenterServices() {
        if( dataCenterServices == null ) {
            dataCenterServices = new DataCenters(this);
        }
        return dataCenterServices;
    }

    @Override
    public String getProviderName() {
        return "Microsoft";
    }

    @Override
    public StorageServices getStorageServices() {
        return new BlobStore(this);
    }
}
